from django.apps import AppConfig


class DittoLastfmConfig(AppConfig):
    name = "ditto.lastfm"
    verbose_name = "Ditto Last.fm"
